@@ -14,7 +14,7 @@ import json
 
 # python 2 and python 3 compatibility library
 import six
-from six.moves.urllib.parse import quote
+from six.moves.urllib.parse import quote, quote
 
 import authress_sdk.models
 from authress_sdk import rest
@@ -41,7 +41,11 @@ class ApiClient(object):
         self.rest_client = rest.RESTClientObject()
         self.default_headers = {}
         # Set default User-Agent.
-        self.default_headers['User-Agent'] = f'Python AuthressSDK version: 1.0'
+
+        this_directory = os.path.abspath(os.path.dirname(__file__))
+        with open(os.path.join(this_directory, '..', 'VERSION')) as version_file:
+          VERSION = version_file.read().strip()
+        self.default_headers['User-Agent'] = f'Python AuthressSDK version: {VERSION}'
 
     def __del__(self):
         self.pool.close()
@@ -557,12 +561,12 @@ class ApiClient(object):
 
           decoded_access_key = json.loads(base64.b64decode(self.access_key))
           payload = {
-            'iss': f"https://api.authress.io/v1/clients/{decoded_access_key['clientId']}",
+            'iss': f"https://api.authress.io/v1/clients/{quote(decoded_access_key['clientId'], safe='')}",
             'aud': decoded_access_key['audience'],
             'exp': datetime.datetime.utcnow() + datetime.timedelta(seconds=86400),
             'sub': decoded_access_key['clientId'],
             'scopes': 'openId'
           }
 
-          self.token = jwt.encode(payload, decoded_access_key['privateKey'], algorithm='RS256', headers={'kid': decoded_access_key['keyId'] })
+          self.token = jwt.encode(payload, decoded_access_key['privateKey'], algorithm='RS256', headers={'kid': decoded_access_key['keyId'] }).decode("utf-8")
           return self.token
\ No newline at end of file
